@@ -33,7 +33,7 @@ namespace indicator
 class DBusIndicators : public Indicators
 {
 public:
-  typedef boost::shared_ptr<DBusIndicators> Ptr;
+  typedef std::shared_ptr<DBusIndicators> Ptr;
 
   DBusIndicators();
   ~DBusIndicators();
@@ -50,10 +50,6 @@ public:
   virtual void OnShowAppMenu(unsigned int xid, int x, int y,
                              unsigned int timestamp);
 
-protected:
-  DBusIndicators(std::string const& dbus_name);
-  bool IsConnected() const;
-
 private:
   class Impl;
   std::unique_ptr<Impl> pimpl;
