@@ -21,6 +21,7 @@
 #include "Indicator.h"
 
 #include <iostream>
+#include <algorithm>
 
 
 namespace unity
@@ -63,18 +64,12 @@ void Indicator::Sync(Indicator::Entries const& new_entries)
 {
   Entries to_rm;
 
-  if (entries_.size() == 0)
-  {
-    to_rm = entries_;
-  }
-  else
+  if (!entries_.empty())
   {
     for (auto entry : entries_)
     {
       if (std::find(new_entries.begin(), new_entries.end(), entry) == new_entries.end())
-      {
         to_rm.push_back(entry);
-      }
     }
   }
 
@@ -120,21 +115,6 @@ Entry::Ptr Indicator::GetEntry(std::string const& entry_id) const
   return Entry::Ptr();
 }
 
-int Indicator::EntryIndex(std::string const& entry_id) const
-{
-  int i = 0;
-  for (auto entry : entries_)
-  {
-    if (entry->id() == entry_id)
-    {
-      return i;
-    }
-    ++i;
-  }
-
-  return -1;
-}
-
 void Indicator::OnEntryShowMenu(std::string const& entry_id, unsigned int xid,
                                 int x, int y, unsigned int button, unsigned int timestamp)
 {
