@@ -36,7 +36,7 @@ namespace indicator
 class Indicator : public sigc::trackable, boost::noncopyable
 {
 public:
-  typedef boost::shared_ptr<Indicator> Ptr;
+  typedef std::shared_ptr<Indicator> Ptr;
   typedef std::list<Entry::Ptr> Entries;
 
   Indicator(std::string const& name);
@@ -48,7 +48,6 @@ public:
 
   void Sync(Entries const& new_entries);
   Entry::Ptr GetEntry(std::string const& entry_id) const;
-  int EntryIndex(std::string const& entry_id) const;
   Entries GetEntries() const;
 
   // Signals
