@@ -24,6 +24,7 @@
 
 #include "Model.h"
 #include "Result.h"
+#include "ResultIterator.h"
 
 namespace unity
 {
@@ -38,6 +39,9 @@ public:
   Results();
   Results(ModelType model_type);
 
+  ResultIterator begin();
+  ResultIterator end();
+
   sigc::signal<void, Result const&> result_added;
   sigc::signal<void, Result const&> result_changed;
   sigc::signal<void, Result const&> result_removed;
