@@ -223,9 +223,9 @@ UnityMTGrabHandlesScreen::raiseHandle (const boost::shared_ptr <const unity::MT:
 void
 UnityMTGrabHandlesScreen::handleEvent(XEvent* event)
 {
-  CompWindow* w, *oldPrev, *oldNext;
+  CompWindow* w;
 
-  w = oldPrev = oldNext = NULL;
+  w = NULL;
 
   switch (event->type)
   {
@@ -292,7 +292,7 @@ UnityMTGrabHandlesScreen::handleEvent(XEvent* event)
           CompWindowVector::const_iterator cit = clientListStacking.begin();
           CompWindowVector::const_iterator oit = mLastClientListStacking.begin();
 
-          for (; cit != clientListStacking.end(); cit++, oit++)
+          for (; cit != clientListStacking.end(); ++cit, oit++)
           {
             /* All clients from this point onwards in cit are invalidated
              * so splice the list to the end of the new client list
@@ -438,29 +438,19 @@ UnityMTGrabHandlesWindow::getOutputExtents(CompWindowExtents& output)
 
 bool
 UnityMTGrabHandlesWindow::glDraw(const GLMatrix&            transform,
-#ifdef USE_GLES
                                  const GLWindowPaintAttrib& attrib,
-#else
-                                 GLFragment::Attrib&      fragment,
-#endif
                                  const CompRegion&          region,
                                  unsigned int              mask)
 {
   /* Draw the window on the bottom, we will be drawing the
    * handles on top */
-#ifdef USE_GLES
   bool status = gWindow->glDraw(transform, attrib, region, mask);
-#else
-  bool status = gWindow->glDraw(transform, fragment, region, mask);
-#endif
 
   if (mHandles && mHandles->visible())
   {
     unsigned int allowedHandles = unity::MT::getLayoutForMask (window->state (), window->actions ());
     unsigned int handle = 0;
 
-    UMTGH_SCREEN (screen);
-
     for(unity::MT::TextureLayout layout : mHandles->layout (allowedHandles))
     {
       /* We want to set the geometry of the handle to the window
@@ -472,17 +462,11 @@ UnityMTGrabHandlesWindow::glDraw(const GLMatrix&            transform,
         GLTexture::MatrixList matl;
         GLTexture::Matrix     mat = tex->matrix();
         CompRegion        paintRegion(region);
-#ifdef USE_GLES
         GLWindowPaintAttrib   wAttrib(attrib);
-#endif
 
         /* We can reset the window geometry since it will be
          * re-added later */
-#ifdef USE_GLES
         gWindow->vertexBuffer()->begin();
-#else
-        gWindow->geometry().reset();
-#endif
 
         /* Not sure what this does, but it is necessary
          * (adjusts for scale?) */
@@ -498,35 +482,22 @@ UnityMTGrabHandlesWindow::glDraw(const GLMatrix&            transform,
          * dim (so we get a nice render for things like
          * wobbly etc etc */
         gWindow->glAddGeometry(matl, reg, paintRegion);
-#ifdef USE_GLES
-        gWindow->vertexBuffer()->end();
-        wAttrib.opacity = mHandles->opacity();
-#else
-        /* Did it succeed? */
-        if (gWindow->geometry().vertices)
-        {
-          fragment.setOpacity(mHandles->opacity());
-          /* Texture rendering set-up */
-          us->gScreen->setTexEnvMode(GL_MODULATE);
-#endif
+
+	if (gWindow->vertexBuffer()->end())
+	{
+	  wAttrib.opacity = mHandles->opacity();
+
           glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
           /* Draw the dim texture with all of it's modified
            * geometry glory */
           gWindow->glDrawTexture(tex,
-#ifdef USE_GLES
                                  transform, wAttrib,
-#else
-                                 fragment,
-#endif
                                  mask | PAINT_WINDOW_BLEND_MASK
                                  | PAINT_WINDOW_TRANSLUCENT_MASK |
                                  PAINT_WINDOW_TRANSFORMED_MASK);
           /* Texture rendering tear-down */
           glBlendFunc(GL_ONE, GL_ONE_MINUS_SRC_ALPHA);
-#ifndef USE_GLES
-          us->gScreen->setTexEnvMode(GL_REPLACE);
         }
-#endif
       }
 
       handle++;
