@@ -20,6 +20,7 @@
 #include <gio/gio.h>
 #include <gmodule.h>
 #include <stdio.h>
+#include <atk-bridge.h>
 
 #include "unitya11y.h"
 #include "unitya11ytests.h"
@@ -37,7 +38,6 @@
 #include "SimpleLauncherIcon.h"
 #include "PanelView.h"
 #include "DashView.h"
-#include "PlacesSimpleTile.h"
 #include "PlacesGroup.h"
 #include "QuicklistView.h"
 #include "QuicklistMenuItem.h"
@@ -49,7 +49,6 @@
 #include "unity-search-bar-accessible.h"
 #include "unity-sctext-accessible.h"
 #include "unity-rvgrid-accessible.h"
-#include "unity-places-simple-tile-accessible.h"
 #include "unity-places-group-accessible.h"
 #include "unity-quicklist-accessible.h"
 #include "unity-quicklist-menu-item-accessible.h"
@@ -64,12 +63,6 @@ static GHashTable* accessible_table = NULL;
 
 static gboolean a11y_initialized = FALSE;
 
-#define INIT_METHOD "gnome_accessibility_module_init"
-#define DESKTOP_SCHEMA "org.gnome.desktop.interface"
-#define ACCESSIBILITY_ENABLED_KEY "toolkit-accessibility"
-#define AT_SPI_SCHEMA "org.a11y.atspi"
-#define ATK_BRIDGE_LOCATION_KEY "atk-bridge-location"
-
 static void
 unity_a11y_restore_environment(void)
 {
@@ -84,102 +77,6 @@ load_unity_atk_util(nux::WindowThread* wt)
   g_type_class_unref(g_type_class_ref(UNITY_TYPE_UTIL_ACCESSIBLE));
 }
 
-/* This method is required because g_setting_new abort if the schema
-   is not present. */
-static gboolean
-has_gsettings_schema(const gchar* schema)
-{
-  const char* const* list_schemas = NULL;
-  gboolean found = FALSE;
-  int i = 0;
-
-  list_schemas = g_settings_list_schemas();
-  for (i = 0; list_schemas [i]; i++)
-  {
-    if (!g_strcmp0(list_schemas[i], schema))
-    {
-      found = TRUE;
-      break;
-    }
-  }
-
-  return found;
-}
-
-static gboolean
-should_enable_a11y(void)
-{
-  GSettings* desktop_settings = NULL;
-  gboolean value = FALSE;
-
-  if (!has_gsettings_schema(DESKTOP_SCHEMA))
-    return FALSE;
-
-  desktop_settings = g_settings_new(DESKTOP_SCHEMA);
-  value = g_settings_get_boolean(desktop_settings, ACCESSIBILITY_ENABLED_KEY);
-
-  g_object_unref(desktop_settings);
-
-  return value;
-}
-
-static gchar*
-get_atk_bridge_path(void)
-{
-  GSettings* atspi_settings = NULL;
-  GVariant *variant = NULL;
-  char* value = NULL;
-
-  if (!has_gsettings_schema(AT_SPI_SCHEMA))
-    return NULL;
-
-  atspi_settings = g_settings_new(AT_SPI_SCHEMA);
-  variant = g_settings_get_value (atspi_settings, ATK_BRIDGE_LOCATION_KEY);
-  value = g_variant_dup_bytestring (variant, NULL);
-
-  g_variant_unref (variant);
-  g_object_unref(atspi_settings);
-
-  return value;
-}
-
-static gboolean
-a11y_invoke_module(const char* module_path)
-{
-  GModule*    handle;
-  void (*invoke_fn)(void);
-
-  if (!module_path)
-  {
-    g_warning("Accessibility: invalid module path (NULL)");
-
-    return FALSE;
-  }
-
-  if (!(handle = g_module_open(module_path, (GModuleFlags)0)))
-  {
-    g_warning("Accessibility: failed to load module '%s': '%s'",
-              module_path, g_module_error());
-
-    return FALSE;
-  }
-
-  if (!g_module_symbol(handle, INIT_METHOD, (gpointer*)&invoke_fn))
-  {
-    g_warning("Accessibility: error library '%s' does not include "
-              "method '%s' required for accessibility support",
-              module_path, INIT_METHOD);
-    g_module_close(handle);
-
-    return FALSE;
-  }
-
-  invoke_fn();
-
-  return TRUE;
-}
-
-/********************************************************************************/
 /*
  * In order to avoid the atk-bridge loading and the GAIL
  * initialization during the gtk_init, it is required to set some
@@ -196,47 +93,31 @@ unity_a11y_preset_environment(void)
 /*
  * Initializes the accessibility (ATK) support on Unity
  *
- * It loads the atk-bridge if required. It checks:
- *  * If the proper gsettings keys are set
- *  * Loads the proper AtkUtil implementation
  */
 void
 unity_a11y_init(nux::WindowThread* wt)
 {
-  gchar* bridge_path = NULL;
-
-  unity_a11y_restore_environment();
-
-  if (!should_enable_a11y())
+  if (a11y_initialized)
     return;
 
+  unity_a11y_restore_environment();
   load_unity_atk_util(wt);
+  atk_bridge_adaptor_init(NULL, NULL);
+  atk_get_root();
 
-  bridge_path = get_atk_bridge_path();
+  a11y_initialized = TRUE;
 
-  if (a11y_invoke_module(bridge_path))
-  {
-    g_debug("Unity Oneiric accessibility started, using bridge on %s",
-            bridge_path);
-
-    atk_get_root();
-
-    a11y_initialized = TRUE;
-  }
-
-  g_free(bridge_path);
-
-// NOTE: we run manually the unit tests while developing by
-// uncommenting this. Take a look to the explanation on
+// NOTE: we run the unit tests manually while developing by
+// uncommenting this. Take a look at the explanation in the
 // unitya11ytests.h header for more information
 
 //  unity_run_a11y_unit_tests ();
 }
 
 /*
- * Finalize the related issues related with the accessibility.
+ * Finalize the issues related with accessibility.
  *
- * It mainly clean the resources related with the accessibility
+ * It mainly cleans the resources related with accessibility
  */
 void
 unity_a11y_finalize(void)
@@ -261,9 +142,9 @@ unity_a11y_finalize(void)
  * that would be add a ->get_accessible method on the nux::View
  * subclasses itself.
  *
- * WARNING: as a reason the previous comment it is true. Take into
- * account that you should be careful with the order you add those
- * defines. The order will be from more specific classes to more
+ * WARNING: as a reason the previous comment is true. Take into
+ * account that you should be careful with the order in which you add
+ * those defines. The order will be from more specific classes to more
  * abstracted classes.
  *
  */
@@ -284,9 +165,6 @@ unity_a11y_create_accessible(nux::Object* object)
   if (object->Type().IsDerivedFromType(DashView::StaticObjectType))
     return unity_dash_view_accessible_new(object);
 
-  if (object->Type().IsDerivedFromType(PlacesSimpleTile::StaticObjectType))
-    return unity_places_simple_tile_accessible_new(object);
-
   if (object->Type().IsDerivedFromType(PlacesGroup::StaticObjectType))
     return unity_places_group_accessible_new(object);
 
@@ -332,7 +210,7 @@ on_object_destroy_cb(nux::Object* base_object,
                      AtkObject* accessible_object)
 {
   /* NOTE: the pair key:value (base_object:accessible_object) could be
-     already removed on on_accessible_destroy_cb. That just mean that
+     already removed on on_accessible_destroy_cb. That just means that
      g_hash_table_remove would return FALSE. We don't add a
      debug/warning message to avoid being too verbose */
 
@@ -344,7 +222,7 @@ on_accessible_destroy_cb(gpointer data,
                          GObject* where_the_object_was)
 {
   /* NOTE: the pair key:value (base_object:accessible_object) could be
-     already removed on on_object_destroy_cb. That just mean that
+     already removed on on_object_destroy_cb. That just means that
      g_hash_table_remove would return FALSE. We don't add a
      debug/warning message to avoid being too verbose */
 
@@ -355,9 +233,9 @@ on_accessible_destroy_cb(gpointer data,
  * Returns the accessible object of a nux::View object
  *
  * This method tries to:
- *   * Check if area has already a accessibility object
- *   * If this is the case, returns that
- *   * If not, creates it and return the object
+ *   * Check if area already has a accessibility object
+ *   * If this is the case, return that
+ *   * If not, create it and return the object
  *
  * FIXME: this should be a temporal method. The best way to implement
  * that would be add a ->get_accessible method on the nux::View
@@ -384,7 +262,7 @@ unity_a11y_get_accessible(nux::Object* object)
     g_hash_table_insert(accessible_table, object, accessible_object);
 
     /* there are two reasons the object should be removed from the
-     * table: base object destroyed, or accessible object
+     * table: base object destroyed or accessible object
      * destroyed
      */
     g_object_weak_ref(G_OBJECT(accessible_object),
