@@ -24,6 +24,7 @@
 #include "test_utils.h"
 
 #include "SwitcherController.h"
+#include "DesktopLauncherIcon.h"
 #include "TimeUtil.h"
 
 
@@ -68,11 +69,11 @@ public:
     view_shown_ = true;
   }
 
-  virtual gboolean OnDetailTimer()
+  virtual bool OnDetailTimer()
   {
     detail_timeout_reached_ = true;
     clock_gettime(CLOCK_MONOTONIC, &detail_timespec_);
-    return FALSE;
+    return false;
   }
 
   unsigned int GetConstructTimeout() const
@@ -127,13 +128,14 @@ TEST(TestSwitcherController, InitialDetailTimeout)
 {
   MockSwitcherController controller;
   std::vector<unity::launcher::AbstractLauncherIcon::Ptr> results;
+  results.push_back(unity::launcher::AbstractLauncherIcon::Ptr(new unity::launcher::DesktopLauncherIcon()));
   struct timespec current;
 
   controller.initial_detail_timeout_length = 2000;
   controller.detail_timeout_length = 20000;
   clock_gettime(CLOCK_MONOTONIC, &current);
 
-  controller.Show(ShowMode::ALL, SortMode::LAUNCHER_ORDER, false, results);
+  controller.Show(ShowMode::ALL, SortMode::LAUNCHER_ORDER, results);
 
   Utils::WaitUntil(controller.detail_timeout_reached_, 3);
   ASSERT_TRUE(controller.detail_timeout_reached_);
@@ -160,11 +162,32 @@ TEST(TestSwitcherController, ShowSwitcher)
 {
   MockSwitcherController controller;
   std::vector<unity::launcher::AbstractLauncherIcon::Ptr> results;
+  results.push_back(unity::launcher::AbstractLauncherIcon::Ptr(new unity::launcher::DesktopLauncherIcon()));
 
-  controller.Show(ShowMode::ALL, SortMode::LAUNCHER_ORDER, false, results);
+  controller.Show(ShowMode::ALL, SortMode::LAUNCHER_ORDER, results);
 
   Utils::WaitUntil(controller.view_shown_, 2);
   ASSERT_TRUE(controller.view_shown_);
 }
 
+TEST(TestSwitcherController, ShowSwitcherNoShowDeskop)
+{
+  MockSwitcherController controller;
+  controller.SetShowDesktopDisabled(true);
+
+  ASSERT_TRUE(controller.IsShowDesktopDisabled());
+  ASSERT_TRUE(controller.StartIndex() == 0);
+}
+
+TEST(TestSwitcherController, ShowSwitcherNoResults)
+{
+  MockSwitcherController controller;
+  controller.SetShowDesktopDisabled(true);
+  std::vector<unity::launcher::AbstractLauncherIcon::Ptr> results;
+
+  controller.Show(ShowMode::CURRENT_VIEWPORT, SortMode::FOCUS_ORDER, results);
+
+  ASSERT_FALSE(controller.Visible());
+}
+
 }
