@@ -35,7 +35,7 @@ public:
   static void WaitUntil(bool& success, unsigned int max_wait = 10)
   {
     bool timeout_reached = false;
-    guint32 timeout_id = ScheduleTimeout(&timeout_reached, max_wait);
+    guint32 timeout_id = ScheduleTimeout(&timeout_reached, max_wait * 1000);
 
     while (!success && !timeout_reached)
       g_main_context_iteration(g_main_context_get_thread_default(), TRUE);
@@ -46,31 +46,17 @@ public:
     EXPECT_TRUE(success);
   }
 
-  static void WaitUntil(std::function<bool()> check_function, bool result = true, unsigned int max_wait = 10)
-  {
-    bool timeout_reached = false;
-    guint32 timeout_id = ScheduleTimeout(&timeout_reached, max_wait * 1000);
-
-    while (!check_function() && !timeout_reached)
-      g_main_context_iteration(g_main_context_get_thread_default(), TRUE);
-
-    if (check_function())
-      g_source_remove(timeout_id);
-
-    EXPECT_EQ(check_function(), result);
-  }
-
   static guint32 ScheduleTimeout(bool* timeout_reached, unsigned int timeout_duration = 10)
-  {
-    return g_timeout_add(timeout_duration*1000, TimeoutCallback, timeout_reached);
-  }
-
-  static guint32 ScheduleTimeoutMSec(bool* timeout_reached, unsigned int timeout_duration = 10)
   {
     return g_timeout_add(timeout_duration, TimeoutCallback, timeout_reached);
   }
 
   static void WaitForTimeout(unsigned int timeout_duration = 10)
+  {
+    WaitForTimeoutMSec(timeout_duration * 1000);
+  }
+
+  static void WaitForTimeoutMSec(unsigned int timeout_duration = 10)
   {
     bool timeout_reached = false;
     guint32 timeout_id = ScheduleTimeout(&timeout_reached, timeout_duration);
@@ -81,17 +67,6 @@ public:
     g_source_remove(timeout_id);
   }
 
-  static void WaitForTimeoutMSec(unsigned int timeout_duration = 10)
-    {
-      bool timeout_reached = false;
-      guint32 timeout_id = ScheduleTimeoutMSec(&timeout_reached, timeout_duration);
-
-      while (!timeout_reached)
-        g_main_context_iteration(g_main_context_get_thread_default(), TRUE);
-
-      g_source_remove(timeout_id);
-    }
-
 private:
   static gboolean TimeoutCallback(gpointer data)
   {
